# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSpatialObjectsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkGaussianSpatialObjectPython
else:
    import _itkGaussianSpatialObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkPointPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkEllipseSpatialObjectPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkSpatialObjectBasePython
import itk.itkBoundingBoxPython
import itk.itkVectorContainerPython
import itk.itkArrayPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkMapContainerPython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkOptimizerParametersPython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVariableLengthVectorPython
import itk.itkArray2DPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkImageRegionPython
import itk.itkSpatialObjectPropertyPython
import itk.itkRGBAPixelPython
class listitkGaussianSpatialObject2_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkGaussianSpatialObject2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkGaussianSpatialObject2_Pointer >::size_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkGaussianSpatialObject2_Pointer

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject2_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject2_Pointer >::difference_type

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject2_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject2_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject2_Pointer >::difference_type
        v: std::list< itkGaussianSpatialObject2_Pointer,std::allocator< itkGaussianSpatialObject2_Pointer > > const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject2_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject2_Pointer >::difference_type

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkGaussianSpatialObject2_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject2_Pointer >::difference_type

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkGaussianSpatialObject2_Pointer,std::allocator< itkGaussianSpatialObject2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject2_Pointer >::difference_type
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkGaussianSpatialObject2_Pointer >::value_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkGaussianSpatialObject2_Pointer >::size_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkGaussianSpatialObject2_Pointer > &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkGaussianSpatialObject2_Pointer >::iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkGaussianSpatialObject2_Pointer >::iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkGaussianSpatialObject2_Pointer >::reverse_iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkGaussianSpatialObject2_Pointer >::reverse_iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkGaussianSpatialObject2_Pointer >::allocator_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkGaussianSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkGaussianSpatialObject2_Pointer >::iterator

        erase(self, first, last) -> std::list< itkGaussianSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkGaussianSpatialObject2_Pointer >::iterator
        last: std::list< itkGaussianSpatialObject2_Pointer >::iterator

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkGaussianSpatialObject2_Pointer
        __init__(self, other) -> listitkGaussianSpatialObject2_Pointer

        Parameters
        ----------
        other: std::list< itkGaussianSpatialObject2_Pointer > const &

        __init__(self, size) -> listitkGaussianSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkGaussianSpatialObject2_Pointer >::size_type

        __init__(self, size, value) -> listitkGaussianSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkGaussianSpatialObject2_Pointer >::size_type
        value: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_swiginit(self, _itkGaussianSpatialObjectPython.new_listitkGaussianSpatialObject2_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkGaussianSpatialObject2_Pointer >::value_type const &"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkGaussianSpatialObject2_Pointer >::value_type const &"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkGaussianSpatialObject2_Pointer >::size_type
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkGaussianSpatialObject2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkGaussianSpatialObject2_Pointer >::size_type
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkGaussianSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkGaussianSpatialObject2_Pointer >::iterator
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkGaussianSpatialObject2_Pointer >::iterator
        n: std::list< itkGaussianSpatialObject2_Pointer >::size_type
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkGaussianSpatialObject2_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_reverse(self)
    __swig_destroy__ = _itkGaussianSpatialObjectPython.delete_listitkGaussianSpatialObject2_Pointer

# Register listitkGaussianSpatialObject2_Pointer in _itkGaussianSpatialObjectPython:
_itkGaussianSpatialObjectPython.listitkGaussianSpatialObject2_Pointer_swigregister(listitkGaussianSpatialObject2_Pointer)
class listitkGaussianSpatialObject3_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkGaussianSpatialObject3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkGaussianSpatialObject3_Pointer >::size_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkGaussianSpatialObject3_Pointer

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject3_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject3_Pointer >::difference_type

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject3_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject3_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject3_Pointer >::difference_type
        v: std::list< itkGaussianSpatialObject3_Pointer,std::allocator< itkGaussianSpatialObject3_Pointer > > const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject3_Pointer >::difference_type
        j: std::list< itkGaussianSpatialObject3_Pointer >::difference_type

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkGaussianSpatialObject3_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject3_Pointer >::difference_type

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkGaussianSpatialObject3_Pointer,std::allocator< itkGaussianSpatialObject3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkGaussianSpatialObject3_Pointer >::difference_type
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkGaussianSpatialObject3_Pointer >::value_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkGaussianSpatialObject3_Pointer >::size_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkGaussianSpatialObject3_Pointer > &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkGaussianSpatialObject3_Pointer >::iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkGaussianSpatialObject3_Pointer >::iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkGaussianSpatialObject3_Pointer >::reverse_iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkGaussianSpatialObject3_Pointer >::reverse_iterator"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkGaussianSpatialObject3_Pointer >::allocator_type"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkGaussianSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkGaussianSpatialObject3_Pointer >::iterator

        erase(self, first, last) -> std::list< itkGaussianSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkGaussianSpatialObject3_Pointer >::iterator
        last: std::list< itkGaussianSpatialObject3_Pointer >::iterator

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkGaussianSpatialObject3_Pointer
        __init__(self, other) -> listitkGaussianSpatialObject3_Pointer

        Parameters
        ----------
        other: std::list< itkGaussianSpatialObject3_Pointer > const &

        __init__(self, size) -> listitkGaussianSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkGaussianSpatialObject3_Pointer >::size_type

        __init__(self, size, value) -> listitkGaussianSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkGaussianSpatialObject3_Pointer >::size_type
        value: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_swiginit(self, _itkGaussianSpatialObjectPython.new_listitkGaussianSpatialObject3_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkGaussianSpatialObject3_Pointer >::value_type const &"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkGaussianSpatialObject3_Pointer >::value_type const &"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkGaussianSpatialObject3_Pointer >::size_type
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkGaussianSpatialObject3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkGaussianSpatialObject3_Pointer >::size_type
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkGaussianSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkGaussianSpatialObject3_Pointer >::iterator
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkGaussianSpatialObject3_Pointer >::iterator
        n: std::list< itkGaussianSpatialObject3_Pointer >::size_type
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkGaussianSpatialObject3_Pointer >::value_type const &

        """
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_reverse(self)
    __swig_destroy__ = _itkGaussianSpatialObjectPython.delete_listitkGaussianSpatialObject3_Pointer

# Register listitkGaussianSpatialObject3_Pointer in _itkGaussianSpatialObjectPython:
_itkGaussianSpatialObjectPython.listitkGaussianSpatialObject3_Pointer_swigregister(listitkGaussianSpatialObject3_Pointer)

def itkGaussianSpatialObject2_New():
    return itkGaussianSpatialObject2.New()

class itkGaussianSpatialObject2(itk.itkSpatialObjectBasePython.itkSpatialObject2):
    r"""Proxy of C++ itkGaussianSpatialObject2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGaussianSpatialObject2_Pointer"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGaussianSpatialObject2_Pointer"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_Clone(self)

    def SetRadiusInObjectSpace(self, _arg):
        r"""
        SetRadiusInObjectSpace(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_SetRadiusInObjectSpace(self, _arg)

    def GetRadiusInObjectSpace(self):
        r"""GetRadiusInObjectSpace(self) -> double const &"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_GetRadiusInObjectSpace(self)

    def SetSigmaInObjectSpace(self, _arg):
        r"""
        SetSigmaInObjectSpace(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_SetSigmaInObjectSpace(self, _arg)

    def GetSigmaInObjectSpace(self):
        r"""GetSigmaInObjectSpace(self) -> double const &"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_GetSigmaInObjectSpace(self)

    def SetCenterInObjectSpace(self, _arg):
        r"""
        SetCenterInObjectSpace(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_SetCenterInObjectSpace(self, _arg)

    def GetCenterInObjectSpace(self):
        r"""GetCenterInObjectSpace(self) -> itkPointD2"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_GetCenterInObjectSpace(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> double const &"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_GetMaximum(self)

    def SquaredZScoreInObjectSpace(self, point):
        r"""
        SquaredZScoreInObjectSpace(self, point) -> double

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_SquaredZScoreInObjectSpace(self, point)

    def SquaredZScoreInWorldSpace(self, point):
        r"""
        SquaredZScoreInWorldSpace(self, point) -> double

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_SquaredZScoreInWorldSpace(self, point)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD2 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_ValueAtInObjectSpace(self, *args)

    def GetEllipsoid(self):
        r"""GetEllipsoid(self) -> itkEllipseSpatialObject2_Pointer"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_GetEllipsoid(self)
    __swig_destroy__ = _itkGaussianSpatialObjectPython.delete_itkGaussianSpatialObject2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGaussianSpatialObject2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGaussianSpatialObject2

        Create a new object of the class itkGaussianSpatialObject2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGaussianSpatialObject2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGaussianSpatialObject2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGaussianSpatialObject2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGaussianSpatialObject2 in _itkGaussianSpatialObjectPython:
_itkGaussianSpatialObjectPython.itkGaussianSpatialObject2_swigregister(itkGaussianSpatialObject2)

def itkGaussianSpatialObject3_New():
    return itkGaussianSpatialObject3.New()

class itkGaussianSpatialObject3(itk.itkSpatialObjectBasePython.itkSpatialObject3):
    r"""Proxy of C++ itkGaussianSpatialObject3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGaussianSpatialObject3_Pointer"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGaussianSpatialObject3_Pointer"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_Clone(self)

    def SetRadiusInObjectSpace(self, _arg):
        r"""
        SetRadiusInObjectSpace(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_SetRadiusInObjectSpace(self, _arg)

    def GetRadiusInObjectSpace(self):
        r"""GetRadiusInObjectSpace(self) -> double const &"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_GetRadiusInObjectSpace(self)

    def SetSigmaInObjectSpace(self, _arg):
        r"""
        SetSigmaInObjectSpace(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_SetSigmaInObjectSpace(self, _arg)

    def GetSigmaInObjectSpace(self):
        r"""GetSigmaInObjectSpace(self) -> double const &"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_GetSigmaInObjectSpace(self)

    def SetCenterInObjectSpace(self, _arg):
        r"""
        SetCenterInObjectSpace(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_SetCenterInObjectSpace(self, _arg)

    def GetCenterInObjectSpace(self):
        r"""GetCenterInObjectSpace(self) -> itkPointD3"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_GetCenterInObjectSpace(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> double const &"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_GetMaximum(self)

    def SquaredZScoreInObjectSpace(self, point):
        r"""
        SquaredZScoreInObjectSpace(self, point) -> double

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_SquaredZScoreInObjectSpace(self, point)

    def SquaredZScoreInWorldSpace(self, point):
        r"""
        SquaredZScoreInWorldSpace(self, point) -> double

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_SquaredZScoreInWorldSpace(self, point)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD3 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_ValueAtInObjectSpace(self, *args)

    def GetEllipsoid(self):
        r"""GetEllipsoid(self) -> itkEllipseSpatialObject3_Pointer"""
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_GetEllipsoid(self)
    __swig_destroy__ = _itkGaussianSpatialObjectPython.delete_itkGaussianSpatialObject3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGaussianSpatialObject3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGaussianSpatialObject3

        Create a new object of the class itkGaussianSpatialObject3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGaussianSpatialObject3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGaussianSpatialObject3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGaussianSpatialObject3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGaussianSpatialObject3 in _itkGaussianSpatialObjectPython:
_itkGaussianSpatialObjectPython.itkGaussianSpatialObject3_swigregister(itkGaussianSpatialObject3)

